
/*
TASK: square
LANG: C++
*/

#include <cmath>
#include <cstdio>
#include <vector>
#include <iostream>
using namespace std;

const double EPS = 1e-9;

struct Point {
    double x, y;
    Point() {
    }
    Point(double x, double y) {
        this->x = x;
        this->y = y;
    }
    Point operator~() {
        return Point(-y, x);
    }
    Point operator*(double p) {
        return Point(x * p, y * p);
    }
    void show() {
        printf("%.4lf %.4lf\n", x, y);
    }
};
Point operator+(Point a, Point b) {
    return Point(a.x + b.x, a.y + b.y);
}
Point operator-(Point a, Point b) {
    return Point (a.x - b.x, a.y - b.y);
}
inline double cross(Point a, Point b, Point c) {
    return a.x * (b.y - c.y) + b.x * (c.y - a.y) + c.x * (a.y - b.y);
}
inline pair <bool, Point> intersect(Point a1, Point a2, Point b1, Point b2) {
    double s1 = cross(a1, a2, b1);
    double s2 = cross(a1, b2, a2);
    if (fabs(s1 + s2) < 1e-9)
        return make_pair(false, Point(0, 0));
    return make_pair(true, b2 + (b1 - b2) * (s2 / (s1 + s2)));
}
inline bool inside(vector <Point>& poly, Point p) {
    bool pos = false;
    bool neg = false;
    bool on = false;
    double x;
    for (int i = 0; i < poly.size(); ++i) {
        x = cross(poly[i], poly[(i + 1) % poly.size()], p);
        if (x < 0.0)
            neg = true;
        else if (x > 0.0)
            pos = true;
    }
    if (pos && neg)
        return false;
    return true;
}

int N;
int d[1 << 10];
int queue[1 << 10];
bool g[1 << 10][1 << 10];
vector <Point> sq[1 << 10];

int main() {
    scanf("%d", &N);
    Point m, a;
    for (int i = 0; i < N; ++i) {
        scanf("%lf %lf %lf %lf", &m.x, &m.y, &a.x, &a.y);
        for (int j = 0; j < 4; ++j) {
            sq[i].push_back(a);
            a = ~(a - m) + m;
//            sq[i][j].show();
        }
    }
    
    for (int i = 0; i < N; ++i)
        for (int j = 0; j < N; ++j) {
            if (i == j) {
                g[i][j] = true;
                continue;
            }
            int cnt = 0;
            for (int k = 0; k < sq[i].size(); ++k)
                if (inside(sq[j], sq[i][k]))
                    ++cnt;
            if (cnt >= 3) {
                g[i][j] = true;
                g[j][i] = true;
                continue;
            }
            pair <bool, Point> z;
            vector <Point> v;
            for (int a = 0; a < sq[i].size(); ++a)
                for (int b = 0; b < sq[j].size(); ++b) {
                    z = intersect(sq[i][a], sq[i][(a + 1) % sq[i].size()], sq[j][b], sq[j][(b + 1) % sq[j].size()]);
                    if (z.first && inside(sq[i], z.second) && inside(sq[j], z.second)) {
                        v.push_back(z.second);
                    }
                }
            for (int a = 0; a < sq[i].size(); ++a)
                if (inside(sq[j], sq[i][a]))
                    v.push_back(sq[i][a]);
            for (int b = 0; b < sq[j].size(); ++b)
                if (inside(sq[i], sq[j][b]))
                    v.push_back(sq[j][b]);
            cnt = 0;
            vector <bool> mark(v.size());
            for (int m = 0; m < v.size(); ++m)
                if (!mark[m]) {
                    mark[m] = true;
                    if (++cnt >= 3)
                        goto ready;
                    for (int k = 0; k < v.size(); ++k)
                        if (!mark[k]) {
                            if (fabs(v[m].x - v[k].x) < EPS && fabs(v[m].y - v[k].y) < EPS)
                                mark[k] = true;
                        }
                }
            ready: ;
            if (cnt >= 3)
                g[i][j] = g[j][i] = true;
        }/*
    for (int i = 0; i < N; ++i, puts(""))
        for (int j = 0; j < N; ++j)
            printf("%d ", g[i][j]);*/
    memset(d, -1, sizeof(d));
    d[0] = 0;
    queue[0] = 0;
    int p3 = 1;
    for (int i = 0; i < p3; ++i) {
        int x = queue[i];
        for (int j = 0; j < N; ++j)
            if (g[i][j] && d[j] == -1) {
                d[j] = d[i] + 1;
                queue[p3++] = j;
            }
    }
    cout << d[N - 1] << endl;
    return 0;
}
